----------------------------------------------------------------------------------
-- Company:  FE, 2014
-- Engineer: A. Trost
-- 
-- Create Date: 09/12/2013 04:06:56 PM
-- Design Name: VGAsinh
-- Module Name: VGAsinh - Behavioral
-- Project Name: lab2, Zynq delavnica 
-- Target Devices: xc7z020clg484-1
-- Tool Versions:  Vivado 2013.3
-- Description: VGA prikaz okna 512x512  
--  clk50 50MHz, VGA 800x600, 72Hz
-- 
-- Revision: 1.2
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.NUMERIC_STD.ALL;

entity VGAsinh is
	Generic (C_RGB_BITS: INTEGER range 3 to 12 := 6);
    Port ( clk50 : in STD_LOGIC;
           rgb_bg : in STD_LOGIC_VECTOR (C_RGB_BITS-1 downto 0);
           hsync : out  STD_LOGIC;
           vsync : out  STD_LOGIC;		
		   rgb : out  STD_LOGIC_VECTOR (C_RGB_BITS-1 downto 0);
		   xy: out  STD_LOGIC_VECTOR (17 downto 0);
           en : out STD_LOGIC);
end VGAsinh;

architecture Behavioral of VGAsinh is
 signal vgaclk: std_logic := '0';
 signal hst: unsigned(10 downto 0):=(others=>'0');
 signal vst: unsigned(9 downto 0):=(others=>'0');
 signal tx, ty: unsigned(8 downto 0);
begin

-- VGA timing proces
pVGA: Process(clk50)
begin
 if rising_edge(clk50) then
	if hst < 1040 then 
		hst<=hst+1;
	else
		hst<=(others=>'0');
		if vst < 666 then
			vst<=vst+1;
		else
			vst<=(others=>'0');
		end if;
	end if;	
				
	en <= '0';
	xy <= (others=>'0');
	
	if hst<800 and vst<600 then
		if hst>=144 and hst<656 and vst>=44 and vst<556 then
			rgb <= (0=>'1', others=>'0'); -- modra barva okna
            xy <= std_logic_vector(tx & ty);
			en <= '1';
		else
			rgb <= rgb_bg; -- barva ozadja
		end if;
	else
		rgb <= (others=>'0'); -- zatemnitev
	end if;
 end if;
end process;

hsync <= '1' when hst>=856 and hst<976 else '0'; 
vsync <= '1' when vst>=637 and vst<643 else '0';   

-- relativni koordinati v oknu
tx <= hst(8 downto 0)-400;  -- 144+256
ty <= vst(8 downto 0)-300;  -- 44+256

end Behavioral;
